function key(id)
{
	return widget.identifier + "-" + id;
}

var from = "Finnboda Varv";
var to = "T-Centralen";
var offset = 5;

function setup()
{
	if (window.widget) {
		from = widget.preferenceForKey(key("from")) || from;
		to = widget.preferenceForKey(key("to")) || to;
		offset = widget.preferenceForKey(key("offset")) || offset;
	
		widget.onhide = onhide;
		widget.onshow = onshow;
	}
	createGenericButton(document.getElementById('done'), "Klar", showfront);
	onshow();
}

function load_html(url, post, success, failure)
{
	var request = new XMLHttpRequest();
	request.onreadystatechange = function () {
		if (request.readyState == 4) {
			if (request.status == 200) {
				success(request.responseText);
			} else {
				failure(request);
			}
		}
	}
	request.open("POST", url, true);
	request.send(post);
}

function show_table(s)
{
	var m = s.match(/<table.*summary(.|\n)*?<\/table>/);
	if (!m) {route_not_found(); return;}
	var restable = m[0];
	m = restable.match(/<tr(.|\n)*?<\/tr>/g);
	var res = [];
	for (i=1; i<=3; ++i) {
		res[i] = {}
		fields = m[i].match(/<td(.|\n)*?<\/td>/g);
		var startstop = fields[3];
		var time = fields[4];
		var route = fields[6];
		
		startstop = startstop.match(/\d\d:\d\d/g);
		res[i].start = startstop[0];
		res[i].stop = startstop[1];
		
		res[i].time = time.match(/\d:\d\d/g)[0];
		
		route = route.toLowerCase();
		route = route.match(/<td.*?>((.|\n)*?)<\/td>/)[1];
		route = route.replace(/<.*?>/g, ",");
		route = route.replace(/,\w*$/, "");
		route = route.replace(/tunnelbanans (.*?)a linje/g, "$1 linje");
		route = route.replace(/buss/g, "");
		route = route.replace(/banan/g, "bana");
		res[i].route = route;
		
		document.getElementById("time" + i).innerHTML = res[i].start + " - " + res[i].stop;
		document.getElementById("route" + i).innerHTML = res[i].route;
		
	}
	
	document.getElementById("next").innerHTML = res[2].start;
}

function clear_front()
{
	document.getElementById("next").innerHTML = "";
	for (i=1; i<=3; ++i) {
		document.getElementById("time" + i).innerHTML = "";
		document.getElementById("route" + i).innerHTML = "";
	}
}

function route_not_found()
{
	clear_front();
	document.getElementById("route1").innerHTML = "Hittar inte resvgen";
}

function error()
{
	clear_front();
	document.getElementById("route1").innerHTML = "Ingen ntverkskoppling";
}

function debug(s)
{
	document.getElementById("debug").innerHTML = s;
}

function myencode(s)
{
	s = encodeURIComponent(s)
	
	// Fix unicode encodings
	s = s.replace(/%C3%A5/gi, "%E5")
	s = s.replace(/%C3%A4/gi, "%E4")
	s = s.replace(/%C3%B6/gi, "%F6")
	
	s = s.replace(/%C3%85/gi, "%C5")
	s = s.replace(/%C3%84/gi, "%C4")
	s = s.replace(/%C3%96/gi, "%D6")
	
	s = s.replace(/%C3%A9/gi, "%E9")
	return s
}

var last_query_from, last_query_to;

function query(from, to, minutes)
{
	if (from != last_query_from || to != last_query_to) {
		clear_front();
		last_query_from = from;
		last_query_to = to;
	}
	
	var hours = Math.floor(minutes / 60);
	var minutes = minutes % 60;
	var offset = hours + ":" + (minutes < 10 ? "0" : "") + minutes;
	var program = "http://reseplanerare.sl.se/bin/query.exe/sn?tpl=index";
	var qs = "REQ0JourneyStopsS0A=255&S=" + myencode(from) + "&REQ0JourneyStopsZ0A=255&Z=" + 
		myencode(to) + "&start=yes&REQ0JourneyTime=%2b" + offset + 
		"&SetGlobalOptionGO_displayDataInTable=yes";
	
	document.getElementById("query").innerHTML = '<a onclick="go_to_sl();" href="#anchor">' + from + "<br/>" + to + "</a>";
	
	load_html(program, qs, show_table, error);
}

function go_to_sl()
{
	var help = "http://reseplanerare.sl.se/bin/help.exe/sn?tpl=index";
	var qs = "REQ0JourneyStopsS0A=255&S=" + myencode(from) + "&REQ0JourneyStopsZ0A=255&Z=" + 
		myencode(to) + "&start=yes&REQ0JourneyTime=%2b" + offset + 
		"&SetGlobalOptionGO_displayDataInTable=yes";
	var link = help + "&" + qs;
	if (window.widget) {
		window.widget.openURL(link);
	} else {
		alert(link);
	}
}

function update()
{
	query(from, to,  offset);
	update_now();
}

var timer = null;
function onshow() 
{
	update();
	if (timer == null) {
		timer = setInterval("update();", 60000);
	}
}

function onhide() {
    if (timer != null) {
        clearInterval(timer);
        timer = null;
    }
}

function showback (event)
{
	var front = document.getElementById("front");
	var back = document.getElementById("back");
	
	if (window.widget)
		widget.prepareForTransition("ToBack");
	
	front.style.display="none";
	back.style.display="block";
	
	if (window.widget)
		setTimeout ('widget.performTransition();', 0);
		
	document.getElementById("from").value = from;
	document.getElementById("to").value = to;
	document.getElementById("offset").value = offset;
}

function showfront ()
{
	var front = document.getElementById("front");
	var back = document.getElementById("back");

	if (window.widget)
		widget.prepareForTransition("ToFront");
	
	front.style.display="block";
	back.style.display="none";
	
	if (window.widget)
		setTimeout ('widget.performTransition();', 0);
	
	from = 	document.getElementById("from").value;
	to = 	document.getElementById("to").value;
	offset = document.getElementById("offset").value;
	
	if (window.widget) {
		widget.setPreferenceForKey(from, key("from"));
		widget.setPreferenceForKey(to, key("to"));
		widget.setPreferenceForKey(offset, key("offset"));
	}
	
	update();
}

function keypress(event)
{
	if (event.keyCode == 13 || event.keyCode == 3) {showfront();}
}

function time()
{
	var t = new Date();
	var hour = t.getHours();
	var minute = t.getMinutes();
	
	var s = (hour < 10 ? "0" : "") + hour + (minute < 10 ? ":0" : ":") + minute;
	return s;
}

function update_now()
{
	document.getElementById("now").innerHTML = time();
}
